@@ -7,7 +7,7 @@ use HTTP::Tiny;
 use JSON::PP;
 use Data::CosineSimilarity;
 
-our $VERSION = '0.1_4';
+our $VERSION = '1.0';
 $VERSION = eval $VERSION;
 
 my $http = HTTP::Tiny->new;
@@ -304,10 +304,12 @@ If the method call fails it sets the L</"error"> message and returns C<undef>.
 
 =head2 test_embedding
 
-    my @test_embedding = $embedding->test_embedding('Some text passage', $dimensions);
+    my $test_embedding = $embedding->test_embedding('Some text passage', $dimensions);
 
 Used for testing code without making a chargeable call to the API.
 
+Provides a CSV string of the same size and format as L<embedding> but with meaningless random data.
+
 Returns a random embedding.  Both parameters are optional.  If a text string is provided, the returned embedding will always be the same random embedding otherwise it will be random and different every time.  The C<dimension> parameter controls the number of elements of the returned CSV string.  If omitted, the string will have the C<text-embedding-ada-002> default of 1536 elements.
 
 =head2 comparator
@@ -378,7 +380,7 @@ L<https://metacpan.org/release/AI::Embedding>
 
 Thanks to the help and support provided by members of Perl Monks L<https://perlmonks.org/>.
 
-Especially L<KCOTT|https://metacpan.org/author/KCOTT> for assistance with unit tests and L<hv|https://perlmonks.org/index.pl?node_id=209409> for suggesting the current C<comparator> implementaion.
+Especially L<Ken Cotterill (KCOTT)|https://metacpan.org/author/KCOTT> for assistance with unit tests and L<Hugo van der Sanden (HVDS)|https://metacpan.org/author/HVDS> for suggesting the current C<comparator> implementaion.
 
 =head1 COPYRIGHT AND LICENSE
 
